from PyQt6 import QtGui

from agstoolbox import getdata


def main_icon() -> QtGui.QIcon:
    return QtGui.QIcon(getdata.path('at_icon.png'))


def main_icon_as_pixmap() -> QtGui.QPixmap:
    return QtGui.QPixmap(getdata.path('at_icon.png'))


def ags_editor_icon() -> QtGui.QIcon:
    return QtGui.QIcon(getdata.path('at_ags_editor_icon.png'))


def ags_editor_as_pixmap() -> QtGui.QPixmap:
    return QtGui.QPixmap(getdata.path('at_ags_editor_icon.png'))


def ags_engine_icon() -> QtGui.QIcon:
    return QtGui.QIcon(getdata.path('at_ags_engine_icon.png'))


def ags_engine_as_pixmap() -> QtGui.QPixmap:
    return QtGui.QPixmap(getdata.path('at_ags_engine_icon.png'))


def icon_refresh() -> QtGui.QIcon:
    return QtGui.QIcon(getdata.path('refresh_icon.png'))


def icon_exit() -> QtGui.QIcon:
    return QtGui.QIcon(getdata.path('exit_icon.png'))


def icon_settings() -> QtGui.QIcon:
    return QtGui.QIcon(getdata.path('settings_icon.png'))


def icon_refresh_as_pixmap() -> QtGui.QPixmap:
    return QtGui.QPixmap(getdata.path('refresh_icon.png'))


def icon_exit_as_pixmap() -> QtGui.QPixmap:
    return QtGui.QPixmap(getdata.path('exit_icon.png'))


def icon_settings_as_pixmap() -> QtGui.QPixmap:
    return QtGui.QPixmap(getdata.path('settings_icon.png'))



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import os
import sys

# TODO: fix to not need this (in Windows, MacOS and Linux)
if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.settings.settings_data import SettingsData
from agstoolbox.core.settings.settings_utils import load_settings_data_from_json_string, \
    save_settings_data_to_json_string


def test_load_json_string_empty():
    # Test that an empty JSON string returns the default SettingsData object
    json_string = ""
    result = load_settings_data_from_json_string(json_string)
    assert isinstance(result, SettingsData)
    assert not result.run_when_os_starts
    assert result.project_search_dirs is None
    assert result.manually_installed_editors_search_dirs is None
    assert result.tools_install_dir is None


def test_load_json_string_all_fields():
    # Test that a JSON string with all fields set returns the correct SettingsData object
    json_string = '{"run_when_os_starts": true, "project_search_dirs": ["dir1", "dir2"], ' \
                  '"manually_installed_editors_search_dirs": "dir3", "tools_install_dir": ' \
                  '"/usr/local/bin"} '
    result = load_settings_data_from_json_string(json_string)
    assert isinstance(result, SettingsData)
    assert result.run_when_os_starts
    assert result.project_search_dirs == ["dir1", "dir2"]
    assert result.manually_installed_editors_search_dirs == ["dir3"]
    assert result.tools_install_dir == "/usr/local/bin"


def test_load_json_string_missing_fields():
    # JSON string with missing fields returns a SettingsData obj with missing fields set to None
    json_string = '{"run_when_os_starts": false, "tools_install_dir": "/usr/local/bin"}'
    result = load_settings_data_from_json_string(json_string)
    assert isinstance(result, SettingsData)
    assert not result.run_when_os_starts
    assert result.project_search_dirs is None
    assert result.manually_installed_editors_search_dirs is None
    assert result.tools_install_dir == "/usr/local/bin"


def test_load_json_string_invalid_json():
    # Test that an invalid JSON string returns empty
    json_string = "not a valid JSON string"
    result = load_settings_data_from_json_string(json_string)
    assert not result.run_when_os_starts
    assert result.project_search_dirs is None
    assert result.manually_installed_editors_search_dirs is None
    assert result.tools_install_dir is None


# Tests for Saving the Json String

def test_save_settings_data_to_json_string_empty():
    # Test that the function returns an empty JSON string when given an empty SettingsData object
    settings_data = SettingsData()
    result = save_settings_data_to_json_string(settings_data)
    assert result == "{}\n"


def test_save_settings_data_to_json_string_all_fields():
    #  returns the correct JSON string when given a SettingsData object with all fields set
    settings_data = SettingsData()
    settings_data.run_when_os_starts = True
    settings_data.project_search_dirs = ["dir1", "dir2"]
    settings_data.manually_installed_editors_search_dirs = ["dir3"]
    settings_data.tools_install_dir = "/usr/local/bin"
    result = save_settings_data_to_json_string(settings_data)
    expected = \
        '{\n' \
        '    "manually_installed_editors_search_dirs": [\n' \
        '        "dir3"\n' \
        '    ],\n' \
        '    "project_search_dirs": [\n' \
        '        "dir1",\n' \
        '        "dir2"\n' \
        '    ],\n' \
        '    "run_when_os_starts": true,\n' \
        '    "tools_install_dir": "/usr/local/bin"\n' \
        '}\n'
    assert result == expected


def test_save_settings_data_to_json_string_missing_fields():
    # returns the correct JSON string when given a SettingsData object with some fields missing
    settings_data = SettingsData()
    settings_data.run_when_os_starts = False
    settings_data.tools_install_dir = "/usr/local/bin"
    result = save_settings_data_to_json_string(settings_data)
    expected = \
        '{\n' \
        '    "run_when_os_starts": false,\n' \
        '    "tools_install_dir": "/usr/local/bin"\n' \
        '}\n'
    assert result == expected



#!/usr/bin/python3
# -*- coding: utf-8 -*-
import os
import sys
from pathlib import Path

if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.utils.file import get_gp_candidates_in_dir, get_unique_list, get_dir

cur_dir = Path(__file__).resolve().parent


def test_get_dir():
    f_path01 = os.path.join(cur_dir, 'resources/fakedir2/Game.agf')
    d_path01 = Path(os.path.join(cur_dir, 'resources/fakedir2')).as_posix()
    f_path02 = os.path.join(cur_dir, 'resources/fakedir2/fakedirA/Game.agf')
    d_path02 = Path(os.path.join(cur_dir, 'resources/fakedir2/fakedirA')).as_posix()
    f_path03 = os.path.join(cur_dir, 'resources/fakedir3/fakedir3/CopyGame/room1.asc')
    d_path03 = Path(os.path.join(cur_dir, 'resources/fakedir3/fakedir3/CopyGame')).as_posix()
    res01 = get_dir(f_path01)
    res02 = get_dir(f_path02)
    res03 = get_dir(f_path03)
    assert res01 == d_path01
    assert res02 == d_path02
    assert res03 == d_path03


def test_get_unique_list():
    # test no duplicates
    input_list: list[str] = ['apple', 'banana', 'orange']
    unique_list = get_unique_list(input_list)
    cmp_list: list[str] = input_list
    cmp_list.sort()
    unique_list.sort()
    assert unique_list == cmp_list

    # test with duplicates
    input_list = ['apple', 'banana', 'orange', 'apple', 'banana']
    unique_list = get_unique_list(input_list)
    cmp_list: list[str] = ['apple', 'banana', 'orange']
    cmp_list.sort()
    unique_list.sort()
    assert unique_list == cmp_list

    # test all duplicates
    input_list = ['apple', 'apple', 'apple', 'apple']
    unique_list = get_unique_list(input_list)
    cmp_list: list[str] = ['apple']
    cmp_list.sort()
    unique_list.sort()
    assert unique_list == cmp_list

    # test empty list
    input_list = []
    unique_list = get_unique_list(input_list)
    assert unique_list == []

    # test single element list
    input_list = ['apple']
    unique_list = get_unique_list(input_list)
    assert unique_list == input_list


def test_get_gp_candidates_in_dir():
    print(cur_dir.as_posix())
    candidates = get_gp_candidates_in_dir(cur_dir.as_posix(), 'Game.agf')
    assert len(candidates) == 4
    c0 = Path(os.path.relpath(candidates[0], cur_dir)).as_posix()
    c1 = Path(os.path.relpath(candidates[1], cur_dir)).as_posix()
    c2 = Path(os.path.relpath(candidates[2], cur_dir)).as_posix()
    c3 = Path(os.path.relpath(candidates[3], cur_dir)).as_posix()
    my_set = {c0, c1, c2, c3}
    assert len(my_set) == 4
    assert 'resources/fakedir2/Game.agf' in my_set
    assert 'resources/fakedir2/fakedirA/Game.agf' in my_set
    assert 'resources/fakedir3/fakedir3/CopyGame/Game.agf' in my_set
    assert 'resources/otherfakedir/MinGame/Game.agf' in my_set



from sys import exit
from PyQt6 import QtWidgets, QtCore, QtGui
from PyQt6.QtCore import QTimer
from PyQt6.QtWidgets import QSystemTrayIcon

from agstoolbox.panels.at_mainpanel import MainWindow
from agstoolbox.at_icons import main_icon
from agstoolbox.core.settings.settings import ConstSettings
from agstoolbox import __title__
from agstoolbox.core.utils.math import clamp
from agstoolbox.system.at_unique_application import unique_application


class AtTrayIcon(QtWidgets.QSystemTrayIcon):

    def __init__(self, icon, parent=None):
        QtWidgets.QSystemTrayIcon.__init__(self, icon, parent)
        self.window = MainWindow()
        self.window.refresh_all()
        menu = QtWidgets.QMenu(parent)

        self.activated.connect(self.onTrayIconActivated)

        action_open_toolbox = QtGui.QAction('Open Toolbox', self)
        action_open_toolbox.triggered.connect(self.open_toolbox)  # load main panel

        action_quit_toolbox = QtGui.QAction('Quit Toolbox', self)
        action_quit_toolbox.triggered.connect(self.exit)

        menu.addAction(action_open_toolbox)
        menu.addAction(action_quit_toolbox)
        self.setContextMenu(menu)

        self.disambiguateTimer = QTimer(self)
        self.disambiguateTimer.setSingleShot(True)
        self.disambiguateTimer.timeout.connect(self.disambiguateTimerTimeout)

    def exit(self):
        QtCore.QCoreApplication.exit()

    def open_toolbox(self):
        tray_icon_rect = self.geometry()
        window_pos = QtCore.QRect()
        window_pos.setSize(QtCore.QSize(
            ConstSettings().DEFAULT_MAIN_PANEL_WIDTH,
            ConstSettings().DEFAULT_MAIN_PANEL_HEIGHT
        ))

        available_geometry = QtGui.QGuiApplication.primaryScreen().availableGeometry()

        pos_x = clamp(tray_icon_rect.x(),
                      available_geometry.x() + 48,
                      available_geometry.width() - available_geometry.x() -
                      window_pos.width() - 48)
        pos_y = clamp(tray_icon_rect.y(),
                      available_geometry.y() + 48,
                      available_geometry.height() - available_geometry.y() -
                      window_pos.height() - 48)

        window_pos.setX(pos_x)
        window_pos.setY(pos_y)
        self.window.setGeometry(window_pos)
        self.window.setWindowState(
            self.window.windowState() &
            ~QtCore.Qt.WindowState.WindowMinimized | QtCore.Qt.WindowState.WindowActive)
        self.window.raise_()
        self.window.show()
        self.window.activateWindow()

    def single_clicked(self):
        self.open_toolbox()

    def double_clicked(self):
        self.open_toolbox()

    def onTrayIconActivated(self, reason):
        if reason == QSystemTrayIcon.ActivationReason.Trigger:
            self.disambiguateTimer.start(ConstSettings().double_click_interval)
        elif reason == QSystemTrayIcon.ActivationReason.DoubleClick:
            self.disambiguateTimer.stop()
            self.double_clicked()

    def disambiguateTimerTimeout(self):
        self.single_clicked()


class UniqueWidget(QtWidgets.QWidget):
    def __init__(self):
        super().__init__()
        QtWidgets.QApplication.instance().another_instance.connect(self.another_instance)

    def another_instance(self):
        self.findChild(AtTrayIcon, __title__).open_toolbox()


def run_tray_indicator(ap_args):
    app = unique_application(__title__, ap_args)
    if not app.is_unique:
        app.exit()
        exit(1)

    # this prevents the tray to close if the main panel is closed,
    # we only exit when quit is explicitly clicked
    app.setQuitOnLastWindowClosed(False)
    ConstSettings().double_click_interval = app.doubleClickInterval()

    w = UniqueWidget()
    tray_icon = AtTrayIcon(main_icon(), w)
    tray_icon.setObjectName(__title__)
    tray_icon.show()
    exit(app.exec())



from __future__ import annotations  # for python 3.8
from PyQt6.QtCore import QThread
from PyQt6.QtCore import pyqtSignal as Signal

from agstoolbox.core.ags.get_local_ags_editors import list_ags_editors_in_dir_list
from agstoolbox.core.gh.download_release import download_release_to_cache
from agstoolbox.core.gh.install_release import install_release_from_cache
from agstoolbox.core.gh.release import Release
from agstoolbox.core.settings.settings import Settings
from agstoolbox.core.ags.get_game_projects import list_game_projects_in_dir_list
from agstoolbox.core.gh.list_releases import list_releases


class ProjUpdateThread(QThread):
    update_started = Signal()
    update_ended = Signal()
    update_canceled = Signal()
    proj_list = None

    def __init__(self):
        QThread.__init__(self)

    def run(self) -> None:
        self.update_started.emit()
        self.proj_list = list_game_projects_in_dir_list(Settings().get_project_search_dirs())
        self.update_ended.emit()

    def stop(self):
        self.update_canceled.emit()


def do_update_projects(update_ended, update_canceled):
    thread = ProjUpdateThread()
    thread.update_ended.connect(update_ended)
    thread.update_canceled.connect(update_canceled)
    thread.start()
    return thread


class ToolsUpdateThreadDownloads(QThread):
    update_started = Signal()
    update_ended = Signal()
    update_canceled = Signal()
    tools_list = None

    def __init__(self):
        QThread.__init__(self)

    def run(self) -> None:
        self.update_started.emit()

        tools = list_releases()
        self.tools_list = tools
        self.update_ended.emit()

    def stop(self):
        self.update_canceled.emit()


def do_update_tools_downloads(update_ended=None, update_canceled=None):
    thread = ToolsUpdateThreadDownloads()
    if update_ended is not None:
        thread.update_ended.connect(update_ended)
    if update_canceled is not None:
        thread.update_canceled.connect(update_canceled)
    thread.start()
    return thread


class ToolsUpdateLocalThread(QThread):
    update_started = Signal()
    update_ended = Signal()
    update_canceled = Signal()
    tools_list = None
    directory_list = None

    def __init__(self, directory_list: list[str]):
        QThread.__init__(self)

        self.tools_list = None
        self.directory_list = directory_list

    def run(self) -> None:
        self.update_started.emit()
        self.tools_list = list_ags_editors_in_dir_list(self.directory_list)
        self.update_ended.emit()

    def stop(self):
        self.update_canceled.emit()


def do_update_tools(directory_list: list[str], update_ended=None, update_canceled=None):
    thread = ToolsUpdateLocalThread(directory_list)
    if update_ended is not None:
        thread.update_ended.connect(update_ended)
    if update_canceled is not None:
        thread.update_canceled.connect(update_canceled)
    thread.start()
    return thread


def do_update_tools_unmanaged(update_ended=None, update_canceled=None):
    dir_list: list[str] = Settings().get_manually_installed_editors_search_dirs()
    return do_update_tools(dir_list, update_ended, update_canceled)


def do_update_tools_managed(update_ended=None, update_canceled=None):
    dir_list: list[str] = list()
    dir_list.append(Settings().get_tools_install_dir())
    return do_update_tools(dir_list, update_ended, update_canceled)


# actual download
class DownloadAManagedToolThread(QThread):
    update_started = Signal()
    update_ended = Signal()
    update_canceled = Signal()
    release: Release = None

    def __init__(self, release: Release = None):
        QThread.__init__(self)

        self.release = release

    def run(self) -> None:
        self.update_started.emit()
        release = self.release
        download_release_to_cache(release)
        install_release_from_cache(release)
        self.update_ended.emit()

    def stop(self):
        self.update_canceled.emit()


def do_download_managed(release: Release, update_ended=None, update_canceled=None):
    thread = DownloadAManagedToolThread(release)
    if update_ended is not None:
        thread.update_ended.connect(update_ended)
    if update_canceled is not None:
        thread.update_canceled.connect(update_canceled)
    thread.start()
    return thread



#!/usr/bin/python3
# -*- coding: utf-8 -*-
import os
import sys
from pathlib import Path

# TODO: fix to not need this (in Windows, MacOS and Linux)
if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.utils.file import join_paths_as_posix
from agstoolbox.core.ags.get_game_projects import is_game_file, \
    text_file_starts_with_xml_Windows1252, list_game_projects_in_dir

cur_dir = Path(__file__).resolve().parent
file_path01 = join_paths_as_posix(cur_dir, 'resources/fakedir2/Game.agf')
file_path02 = join_paths_as_posix(cur_dir, 'resources/fakedir2/fakedirA/Game.agf')
file_path03 = join_paths_as_posix(cur_dir, 'resources/fakedir3/fakedir3/CopyGame/Game.agf')
file_path04 = join_paths_as_posix(cur_dir, 'resources/otherfakedir/MinGame/Game.agf')


def test_text_file_starts_with_xml_Windows1252():
    assert text_file_starts_with_xml_Windows1252(file_path01) is False
    assert text_file_starts_with_xml_Windows1252(file_path02) is False
    assert text_file_starts_with_xml_Windows1252(file_path03) is True
    assert text_file_starts_with_xml_Windows1252(file_path04) is True


def test_is_game_file():
    assert is_game_file(file_path01) is False
    assert is_game_file(file_path02) is False
    assert is_game_file(file_path03) is True
    assert is_game_file(file_path04) is True


def test_list_game_projects_in_dir():
    projects = list_game_projects_in_dir(cur_dir.as_posix())
    assert len(projects) == 2
    proj_copy_game = next((p for p in projects if p.name == 'CopyGameTitle'), None)
    proj_min_game = next((p for p in projects if p.name == 'MinGame'), None)
    assert proj_copy_game is not None
    assert proj_min_game is not None



# -*- coding: utf-8 -*-
import os.path
import sys

# am I running from pyinstaller ?
if getattr(sys, 'frozen', False):
    # yes, running from pyinstaller
    data_path = os.path.join(os.path.join(sys._MEIPASS), 'data')  # pylint: disable=no-member
elif __file__:
    # no, this is the realworld
    data_path = os.path.join(os.path.dirname(__file__), 'data')


def path(filename):
    """
    Returns path for filename in data folder, like images needed for the ui.
    """
    return os.path.join(data_path, filename)



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import os
import sys
from datetime import datetime, timedelta

# TODO: fix to not need this (in Windows, MacOS and Linux)
if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.utils.time import internal_s_ago


def test_internal_s_ago_just_now():
    now = datetime.utcnow()
    diff = timedelta()
    assert internal_s_ago(now, diff) == "just now"


def test_internal_s_ago_minutes_ago():
    now = datetime.utcnow()
    t = now - timedelta(minutes=10)
    diff = now - t
    assert internal_s_ago(t, diff) == "10 minutes ago"


def test_internal_s_ago_hours_ago():
    now = datetime.utcnow()
    t = now - timedelta(hours=3)
    diff = now - t
    assert internal_s_ago(t, diff) == "3 hours ago"


def test_internal_s_ago_days_ago():
    now = datetime.utcnow()
    t = now - timedelta(days=2)
    diff = now - t
    assert internal_s_ago(t, diff) == "2 days ago"


def test_internal_s_ago_date_format():
    now = datetime.utcnow()
    t = now - timedelta(days=7)
    diff = now - t
    assert internal_s_ago(t, diff) == t.strftime("%d/%m/%Y")



from codecs import open
from pathlib import Path

from setuptools import setup
import re


with open('src/agstoolbox/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)


this_directory = Path(__file__).parent
long_description = (this_directory / "README.rst").read_text()

setup(
    name='agstoolbox',
    version=version,
    description='Utility to help manage Adventure Game Studio Projects and Editors.',
    long_description=long_description,
    url='https://github.com/ericoporto/agstoolbox',
    download_url='https://github.com/ericoporto/agstoolbox/tarball/' + version,
    author='erico',
    author_email='eri0onpm@gmail.com',
    license='MIT',
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License'
    ],
    keywords=['AGS Toolbox', 'Adventure Game Studio', 'development', 'ags', 'Game Development',
              'gamedev'],
    install_requires=['pyqt6', 'requests', 'defusedxml', 'platformdirs', 'pefile'],
    packages=["agstoolbox"],
    package_dir={"": "src"},
    scripts=["agstoolbox", "atbx"],
    package_data={
        'agstoolbox': ['data/*.png']
    },
)



#!/usr/bin/python3
# -*- coding: utf-8 -*-
import os
import sys

if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.version.version_utils import tag_to_version_str, tag_to_family, \
    family_to_major, family_to_minor, \
    version_str_to_int, family_str_to_int, tag_to_version


def test_tag_to_version_str():
    assert tag_to_version_str("v.3.5.1.14") == "3.5.1.14"
    assert tag_to_version_str("v.3.  6.1.14") == "3.6.1.14"
    assert tag_to_version_str("v.4.0.0.14") == "4.0.0.14"
    assert tag_to_version_str("3.4.3.14") == "3.4.3.14"
    assert tag_to_version_str("version.3.3.1.14") == "3.3.1.14"
    assert tag_to_version_str("vivaldi.1") == "vivaldi.1"
    assert tag_to_version_str("v1.0.0.0") == "1.0.0.0"
    assert tag_to_version_str("version.1.2.3.4") == "1.2.3.4"
    assert tag_to_version_str("v1.2.3.4") == "1.2.3.4"
    assert tag_to_version_str("1.2.3.4") == "1.2.3.4"
    assert tag_to_version_str("v1.2.3") == "1.2.3.0"
    assert tag_to_version_str("1.2.3") == "1.2.3.0"
    assert tag_to_version_str("v1.2") == "1.2.0.0"
    assert tag_to_version_str("1.2") == "1.2.0.0"
    assert tag_to_version_str("v1") == "1.0.0.0"
    assert tag_to_version_str("1") == "1.0.0.0"
    assert tag_to_version_str("not.a.tag") == "not.a.tag"
    assert tag_to_version_str("") == ""


def test_tag_to_family():
    assert tag_to_family("v.3.5.1.14") == "3.5"
    assert tag_to_family("v.3.6.1.14") == "3.6"
    assert tag_to_family("v.4.0.0.14") == "4.0"
    assert tag_to_family("3.4.3.14") == "3.4"
    assert tag_to_family("3.3.1.14") == "3.3"
    assert tag_to_family("vivaldi.1") == "vivaldi.1"
    assert tag_to_family("v1.0.0.0") == "1.0"
    assert tag_to_family("version.1.2.3.4") == "1.2"
    assert tag_to_family("v1.2.3.4") == "1.2"
    assert tag_to_family("1.2.3.4") == "1.2"
    assert tag_to_family("v1.2.3") == "1.2"
    assert tag_to_family("1.2.3") == "1.2"
    assert tag_to_family("v1.2") == "1.2"
    assert tag_to_family("1.2") == "1.2"
    assert tag_to_family("v1") == "1.0"
    assert tag_to_family("1") == "1.0"
    assert tag_to_family("not.a.tag") == "not.a.tag"
    assert tag_to_family("") == ""


def test_family_to_major():
    assert family_to_major("3.4") == "3"
    assert family_to_major("3.7") == "3"
    assert family_to_major("4.4") == "4"
    assert family_to_major("73.4") == "73"
    assert family_to_major("experimental") == "experimental"


def test_family_to_minor():
    assert family_to_minor("3.4") == "4"
    assert family_to_minor("3.7") == "7"
    assert family_to_minor("4.2") == "2"
    assert family_to_minor("73.4") == "4"
    assert family_to_minor("experimental") == "experimental"


def test_version_str_to_int():
    assert version_str_to_int("v.3.5.1.14") == 3005001014
    assert version_str_to_int("v.3.  6.1.14") == 3006001014
    assert version_str_to_int("v.4.0.0.14") == 4000000014
    assert version_str_to_int("3.4.3.14") == 3004003014
    assert version_str_to_int("version.3.3.1.14") == 3003001014
    assert version_str_to_int("vivaldi.1") == -1


def test_family_str_to_int():
    assert family_str_to_int("3.5") == 3005000000
    assert family_str_to_int("3.6") == 3006000000
    assert family_str_to_int("4.0") == 4000000000
    assert family_str_to_int("3.4") == 3004000000
    assert family_str_to_int("3.3") == 3003000000
    assert family_str_to_int("vivaldi.1") == -1


def test_tag_to_version():
    v = tag_to_version("v.3.5.1.14")
    assert v.as_int == 3005001014
    assert v.major == "3"
    assert v.minor == "5"
    assert v.family == "3.5"
    assert v.family_as_int == 3005000000



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
.. module:: agstoolbox
   :platform: Windows
   :synopsis: An application to help managing AGS Editor versions
.. moduleauthor:: Érico Vieira Porto
"""

from os import environ as environ

# TODO: figure out how to avoid import when no graphical environment exists
from agstoolbox.at_trayindicator import run_tray_indicator
from agstoolbox.core.cmdline import cmdline


def main():
    """"
    agstoolbox main routine
    When you use `python -m agstoolbox`, the main routine is called.
    If you use `pip install agstoolbox`, typing agstoolbox will also call this routine.
    The objective of this function is to:
    1. load agstoolbox when called without args
    2. seeing the current version by using `--version`, and not opening agstoolbox
    """
    environ["LIBOVERLAY_SCROLLBAR"] = "0"

    ap_args = cmdline(False)
    run_tray_indicator(ap_args)


def Run():
    main()


if __name__ == "__main__":
    main()



#!/usr/bin/python3
# -*- coding: utf-8 -*-
import os
import sys
from pathlib import Path

if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.utils.file import join_paths_as_posix
from agstoolbox.core.utils.pe import is_valid_exe, get_exe_information

cur_dir = str(Path(__file__).resolve().parent)

file_path01 = join_paths_as_posix(cur_dir, 'resources/fakedir1/AGSEditor.exe')
file_path02 = join_paths_as_posix(cur_dir, 'resources/fakedir2/fakedirA/AGSEditor.exe')
file_path03 = join_paths_as_posix(cur_dir, 'resources/fakedir3/fakedir3/CopyGame/Game.agf')
file_path04 = join_paths_as_posix(cur_dir, 'resources/otherfakedir/MinGame/Game.agf')


def test_is_valid_exe():
    assert is_valid_exe(file_path01) is True
    assert is_valid_exe(file_path02) is True
    assert is_valid_exe(file_path03) is False
    assert is_valid_exe(file_path04) is False


def test_get_exe_information():
    path01_exe_nfo = get_exe_information(file_path01)
    path02_exe_nfo = get_exe_information(file_path02)
    path03_exe_nfo = get_exe_information(file_path03)
    path04_exe_nfo = get_exe_information(file_path04)
    assert path01_exe_nfo.product_name == 'Made with Adventure Game Studio'
    assert path01_exe_nfo.internal_name == 'acwin'
    assert path01_exe_nfo.original_filename == 'acwin.exe'
    assert path02_exe_nfo.product_name == 'Adventure Game Studio'
    assert path02_exe_nfo.internal_name == 'AGSEditor.exe'
    assert path02_exe_nfo.original_filename == 'AGSEditor.exe'
    assert path03_exe_nfo.product_name is None
    assert path04_exe_nfo.product_name is None



#!/usr/bin/python3
# -*- coding: utf-8 -*-
import json
import os
import sys
from pathlib import Path

# TODO: fix to not need this (in Windows, MacOS and Linux)
if os.path.isdir(os.path.join(".", "src")) and os.path.isfile(os.path.join(".", "setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/agstoolbox"))

from agstoolbox.core.gh.list_releases import parse_releases

cur_dir = Path(__file__).resolve().parent


def test_parse_releases():
    f = open(os.path.join(cur_dir, 'resources/gh_releases.json'))
    response_json = json.load(f)
    releases = parse_releases(response_json)
    assert len(releases) == 90
    assert releases[43].tag == "v.3.6.0.15"
    assert releases[44].tag == "v.3.6.0.14"
    assert releases[46].tag == "v.3.6.0.13"
    assert releases[46].name == "v.3.6.0.13 - Alpha 14"
    assert releases[46].url == "https://api.github.com/repos/adventuregamestudio/ags/releases/56166627"
    assert releases[46].archive_name == "AGS-3.6.0.13-Alpha14.zip"
    assert releases[46].archive_url == \
           "https://github.com/adventuregamestudio/ags/releases/download/v.3.6.0.13/AGS-3.6.0.13-Alpha14.zip"
    assert releases[46].archive_size == 25219327
    assert releases[0].tag == "v.3.6.0.47"
    assert releases[0].name == "3.6.0 Release"
    assert releases[0].url == "https://api.github.com/repos/adventuregamestudio/ags/releases/97715961"
    assert releases[0].archive_name == "AGS-3.6.0.47.zip"
    assert releases[0].archive_url == \
           "https://github.com/adventuregamestudio/ags/releases/download/v.3.6.0.47/AGS-3.6.0.47.zip"
    assert releases[0].archive_size == 40475597
